@@ -30,6 +30,7 @@
 #include <QSet>
 #include <QMutableSetIterator>
 #include <QByteArray>
+#include <QElapsedTimer>
 
 //for sysconf
 #include <unistd.h>
@@ -51,7 +52,7 @@ namespace KSysGuard
         mProcesses.insert(-1, &mFakeProcess);
         mElapsedTimeMilliSeconds = 0;
         mHavePreviousIoValues = false;
-        mUpdateFlags = nullptr;
+        mUpdateFlags = {};
         mUsingHistoricalData = false;
         q = q_ptr;
     }
@@ -70,7 +71,7 @@ namespace KSysGuard
       ProcessesATop *mHistoricProcesses; ///< A way to get historic information about processes
       bool mIsLocalHost; ///< Whether this is localhost or not
 
-      QTime mLastUpdated; ///< This is the time we last updated.  Used to calculate cpu usage.
+      QElapsedTimer mLastUpdated; ///< This is the time we last updated.  Used to calculate cpu usage.
       long mElapsedTimeMilliSeconds; ///< The number of milliseconds  (1000ths of a second) that passed since the last update
 
       Processes::UpdateFlags mUpdateFlags;
